# Default Flux Output Files

The primary output file type for the VIC Classic Driver is the flux file, which contains information about moisture and energy fluxes for each time step. The number of variables in this file depends on the values of `FULL_ENERGY` and `FROZEN_SOIL` in the [global parameter file](GlobalParam.md); when either `FULL_ENERGY` or `FROZEN_SOIL` are true, the file will contain the same number of columns as found in the PILPS-2C files for comparison purposes. Flux files are always written, regardless of the mode of operation. Flux files begin with the prefix `fluxes_`.

Each output file contains model output from one grid cell. The files use the naming convention `fluxes_xx.xx_yy.yy`, where `xx.xx` is the latitude, and `yy.yy` is the longitude. The number of decimal places in the output filename is determined by `GRID_DECIMAL` in the [global parameter file](GlobalParam.md), while the latitude and longitude values come from the [soil parameter file](SoilParam.md).

## Flux File Format
| Column                                                                                                            	| Variable Name   	| Units                    	| Description                                                         	|
|-------------------------------------------------------------------------------------------------------------------	|-----------------	|--------------------------	|---------------------------------------------------------------------	|
| 1                                                                                                                 	| year            	| year                     	| Year of current record                                              	|
| 2                                                                                                                 	| month           	| month                    	| Month of current record                                             	|
| 3                                                                                                                 	| day             	| day                      	| Day of current record                                               	|
| 4                                                                                                                 	| hour            	| hour                     	| Hour of current record (if time step is sub-daily)                  	|
| 5                                                                                                                 	| OUT_PREC        	| mm                       	| Precipitation for current record                                    	|
| 6                                                                                                                 	| OUT_EVAP        	| mm                       	| Evaporation for current record                                      	|
| 7                                                                                                                 	| OUT_RUNOFF      	| mm                       	| Runoff for current record                                           	|
| 8                                                                                                                 	| OUT_BASEFLOW    	| mm                       	| Baseflow for current record                                         	|
| 9                                                                                                                 	| OUT_WDEW        	| mm                       	| Canopy interception of liquid water                                 	|
| 10: Nlayer+9                                                                                                      	| OUT_SOIL_LIQ    	| mm                       	| Moisture content of each soil layer                                 	|
| OUT_RAD_TEMP is only output when `FULL_ENERGY` or `FROZEN_SOIL` is TRUE in the global parameter file                |                 	|                          	|                                                                     	|
| Nlayer+10                                                                                                         	| OUT_RAD_TEMP    	| K                        	| Radiative temperature of the surface                                	|
| Nlayer+11                                                                                                         	| OUT_SWNET     	| W/m2                     	| Net shortwave radiation at the surface                              	|
| Nlayer+12                                                                                                         	| OUT_R_NET       	| W/m2                     	| Net radiation at the surface, includes long and shortwave radiation 	|
| OUT_LATENT is only output when `FULL_ENERGY` or `FROZEN_SOIL` is TRUE in the global parameter file                  |                 	|                          	|                                                                     	|
| Nlayer+13                                                                                                         	| OUT_LATENT      	| W/m2                     	| Latent heat from the surface                                        	|
| Nlayer+14                                                                                                         	| OUT_EVAP_CANOP  	| mm                       	| Evaporation from canopy storage                                     	|
| Nlayer+15                                                                                                         	| OUT_TRANSP_VEG  	| mm                       	| Transpiration from the vegetation                                   	|
| Nlayer+16                                                                                                         	| OUT_EVAP_BARE   	| mm                       	| Evaporation from bare soil                                          	|
| Nlayer+17                                                                                                         	| OUT_SUB_CANOP   	| mm                       	| Sublimation from canopy interception                                	|
| Nlayer+18                                                                                                         	| OUT_SUB_SNOW    	| mm                       	| Sublimation from ground snow pack                                   	|
| The following four variables are only output when `FULL_ENERGY` or `FROZEN_SOIL` is TRUE in the global parameter file |                	|                          	|                                                                     	|
| Nlayer+19                                                                                                         	| OUT_SENSIBLE    	| W/m2                     	| Sensible heat flux from the surface                                 	|
| Nlayer+20                                                                                                         	| OUT_GRND_FLUX   	| W/m2                     	| Ground heat flux plus heat storage in the top soil layer            	|
| Nlayer+21                                                                                                         	| OUT_DELTAH      	| W/m2  	                | Rate of change in heat storage                                      	|
| Nlayer+22                                                                                                         	| OUT_FUSION      	| W/m2                     	| Net energy used to melt/freeze soil moisture                        	|
| Nlayer+23                                                                                                         	| OUT_AERO_RESIST 	| s/m                      	| Aerodynamic resistance                                              	|
| Nlayer+24                                                                                                         	| OUT_SURF_TEMP   	| C                        	| Surface temperature                                                 	|
| Nlayer+25                                                                                                         	| OUT_ALBEDO      	| fraction                 	| Albedo of surface cover                                             	|
| Nlayer+26                                                                                                         	| OUT_REL_HUMID   	| fraction                 	| Relative humidity                                                   	|
| Nlayer+27                                                                                                         	| OUT_IN_LONG     	| W/m2                     	| Incoming longwave at ground surface (under vegetation)              	|
| Nlayer+28                                                                                                         	| OUT_AIR_TEMP    	| C        	                | Air temperature                                                     	|
| Nlayer+29                                                                                                         	| OUT_WIND        	| m/s                      	| Near surface wind speed                                             	|
