# VIC Vegetation Library File

Vegetation parameters needed for each vegetation type used in the VIC model are provided in a column format ASCII file as described in this document. Parameters are given for different vegetation types, and are referenced by the [vegetation parameter file](VegParam.md), which provides information about the number of vegetation types per grid cell, and their fractional coverage. A header may be added to the top of the file if the first column contains a '#'. Comments can also be added to the end of each line in the vegetation library file.

## Vegetation Library File Format

| Variable Name                                                     | Units                 | Number of Values  | Description                                                                                                                                                           |
|-----------------------------------------------------------------  |---------------------  |------------------ |---------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| veg_class                                                         | N/A                   | 1                 | Vegetation class identification number (reference index for library table)                                                                                            |
| overstory                                                         | N/A                   | 1                 | Flag to indicate whether or not the current vegetation type has an overstory (TRUE for overstory present [*e.g. trees*], FALSE for overstory not present [*e.g. grass*])  |
| rarc                                                              | s/m                   | 1                 | Architectural resistance of vegetation type (~2 s/m)                                                                                                                  |
| rmin                                                              | s/m                   | 1                 | Minimum stomatal resistance of vegetation type (~100 s/m)                                                                                                             |
| LAI                                                               | fraction              | 12                | Leaf-area index of vegetation type                                                                                                                                    |
| FCANOPY  (Only present if VEGLIB_FCAN=TRUE in [global parameter file](GlobalParam.md) | fraction              | 12                | Partial vegetation cover fraction                                                                                                                                     |
| albedo                                                            | fraction              | 12                | Shortwave albedo for vegetation type                                                                                                                                  |
| rough                                                             | m                     | 12                | Vegetation roughness length (typically `0.123 * vegetation height`)                                                                                                     |
| displacement                                                      | m                     | 12                | Vegetation displacement height (typically `0.67 * vegetation height`)                                                                                                   |
| wind_h                                                            | m                     | 1                 | Height at which wind speed is measured. **If using snow interception routines please read the [documentation on wind_h](Definitions/#wind_h)**.                                                          |
| RGL                                                               | W/m<sup>2</sup>                 | 1                 | Minimum incoming shortwave radiation at which there will be transpiration. For trees this is about 30 W/m<sup>2</sup>, for crops about 100 W/m<sup>2</sup>.                               |
| rad_atten                                                         | fract                 | 1                 | Radiation attenuation factor. Normally set to 0.5, though may need to be adjusted for high latitudes.                                                                 |
| wind_atten                                                        | fract                 | 1                 | Wind speed attenuation through the overstory. The default value has been 0.5.                                                                                         |
| trunk_ratio                                                       | fract                 | 1                 | Ratio of total tree height that is trunk (no branches). The default value has been 0.2.                                                                               |
| Ctype (Only present if VEGLIB_PHOTO=TRUE in [global parameter file](GlobalParam.md) | 0 or 1 (0 = C3, 1 = C4) | 1                 | Photosynthetic pathway (NOTE: the previous input values of "C3" and "C4" are still accepted but are deprecated.                                                       |
| MaxCarboxRate (Only present if VEGLIB_PHOTO=TRUE in [global parameter file](GlobalParam.md) | mol CO2/m2s           | 1                 | Maximum carboxlyation rate at 25 deg C                                                                                                                                |
| MaxETransport (C3) or CO2Specificity (C4) (Only present if VEGLIB_PHOTO=TRUE in [global parameter file](GlobalParam.md) | mol CO2/m2s           | 1                 | Maximum electron transport rate at 25 deg C (C3) or CO2 specificity at 25 deg C (C4)                                                                                  |
| LightUseEff (Only present if VEGLIB_PHOTO=TRUE in [global parameter file](GlobalParam.md) | mol CO2/mol photons   | 1                 | Light-use efficiency                                                                                                                                                  |
| NscaleFlag (Only present if VEGLIB_PHOTO=TRUE in [global parameter file](GlobalParam.md) | 0 or 1                | 1                 | 1 = nitrogen-scaling factors are applicable to this veg class                                                                                                         |
| Wnpp_inhib (Only present if VEGLIB_PHOTO=TRUE in [global parameter file](GlobalParam.md) | fract                 | 1                 | Fraction of maximum moisture storage in top soil layer above which photosynthesis begins to be inhibited by wet conditions                                            |
| NPPfactor_sat (Only present if VEGLIB_PHOTO=TRUE in [global parameter file](GlobalParam.md) | fract                 | 1                 | Ratio of NPP under saturated conditions (moisture fraction = 1.0) to NPP at moisture fraction = Wnpp_inhib                                                            |
| comment                                                           | N/A                   | 1                 | Comment block for vegetation type. Model skips end of line so spaces are valid entries.                                                                                |

## Example Vegetation Library File:

    #Class  OvrStry Rarc    Rmin    JAN-LAI FEB-LAI MAR-LAI APR-LAI MAY-LAI JUN-LAI JUL-LAI AUG-LAI SEP-LAI OCT-LAI NOV-LAI DEC-LAI JAN-ALB FEB_ALB MAR-ALB APR-ALB MAY-ALB JUN-ALB JUL-ALB AUG-ALB SEP-ALB OCT-ALB NOV-ALB DEC-ALB JAN-ROU FEB-ROU MAR-ROU APR-ROU MAY-ROU JUN-ROU JUL-ROU AUG-ROU SEP-ROU OCT-ROU NOV-ROU DEC-ROU JAN-DIS FEB-DIS MAR-DIS APR-DIS MAY-DIS JUN-DIS JUL-DIS AUG-DIS SEP-DIS OCT-DIS NOV-DIS DEC-DIS WIND_H  RGL     rad_atten    wind_atten  trunk_ratio   COMMENT
    2   0   25.0    220.    0.000   0.000   0.000   0.000   1.000   2.500   4.000   4.500   0.500   0.000   0.000   0.000   0.10    0.10    0.10    0.10    0.20    0.20    0.20    0.20    0.20    0.10    0.10    0.10    0   0   0   0   0.0615  0.123   0.246   0.3075  0.3075  0   0   0   0   0   0   0   0.335   0.67    1.34    1.675   1.675   0   0   0   2.0 100 0.5      0.5     0.2           Corn Field
    3   0   25.0    220.    0.000   0.000   0.000   0.000   1.000   3.000   5.000   6.000   3.000   0.000   0.000   0.000   0.10    0.10    0.10    0.10    0.20    0.20    0.20    0.20    0.20    0.10    0.10    0.10    0   0   0   0   0.03075 0.0615  0.09225 0.09225 0.09225 0   0   0   0   0   0   0   0.1675  0.335   0.5025  0.5025  0.5025  0   0   0   2.  100 0.5      0.5     0.2           Soy Field
