/******************************************************************************
 * @section DESCRIPTION
 *
 * This routine sets the metadata structure for VIC state variables
 *****************************************************************************/

#include <vic_driver_shared_image.h>
#include <rout.h>

/******************************************************************************
 * @brief    Set output met data information
 *****************************************************************************/
void
set_state_meta_data_info()
{
    size_t                 v;

    extern option_struct   options;
    extern metadata_struct state_metadata[N_STATE_VARS + N_STATE_VARS_EXT];

    // Build the list of state variables

    // Set missing and/or default values
    for (v = 0; v < (N_STATE_VARS + N_STATE_VARS_EXT); v++) {
        // Set default string values
        strcpy(state_metadata[v].varname, MISSING_S);
        strcpy(state_metadata[v].long_name, MISSING_S);
        strcpy(state_metadata[v].standard_name, MISSING_S);
        strcpy(state_metadata[v].units, MISSING_S);
        strcpy(state_metadata[v].description, MISSING_S);
        // Set default number of elements
        state_metadata[v].nelem = 1;
    }

    // STATE_SOIL_MOISTURE
    strcpy(state_metadata[STATE_SOIL_MOISTURE].varname, "STATE_SOIL_MOISTURE");
    strcpy(state_metadata[STATE_SOIL_MOISTURE].long_name, "soil_moisture");
    strcpy(state_metadata[STATE_SOIL_MOISTURE].standard_name,
           "soil_layer_moisture");
    strcpy(state_metadata[STATE_SOIL_MOISTURE].units, "mm");
    strcpy(state_metadata[STATE_SOIL_MOISTURE].description,
           "soil total moisture contents including ice for each soil layer");

    // STATE_SOIL_ICE
    strcpy(state_metadata[STATE_SOIL_ICE].varname, "STATE_SOIL_ICE");
    strcpy(state_metadata[STATE_SOIL_ICE].long_name, "soil_ice");
    strcpy(state_metadata[STATE_SOIL_ICE].standard_name,
           "soil_moisture_ice_depth");
    strcpy(state_metadata[STATE_SOIL_ICE].units, "mm");
    strcpy(state_metadata[STATE_SOIL_ICE].description,
           "soil ice content for each soil layer");

    // STATE_CANOPY_WATER
    strcpy(state_metadata[STATE_CANOPY_WATER].varname, "STATE_CANOPY_WATER");
    strcpy(state_metadata[STATE_CANOPY_WATER].long_name, "canopy_water");
    strcpy(state_metadata[STATE_CANOPY_WATER].standard_name, "water_in_canopy");
    strcpy(state_metadata[STATE_CANOPY_WATER].units, "mm");
    strcpy(state_metadata[STATE_CANOPY_WATER].description,
           "amount of water stored in the vegetation canopy");

    if (options.CARBON) {
        // STATE_ANNUALNPP
        strcpy(state_metadata[STATE_ANNUALNPP].varname, "STATE_ANNUALNPP");
        strcpy(state_metadata[STATE_ANNUALNPP].long_name, "annualnpp");
        strcpy(state_metadata[STATE_ANNUALNPP].standard_name,
               "running_total_annual_NPP");
        strcpy(state_metadata[STATE_ANNUALNPP].units, "g m-2");
        strcpy(state_metadata[STATE_ANNUALNPP].description,
               "running total annual NPP");

        // STATE_ANNUALNPPPREV
        strcpy(state_metadata[STATE_ANNUALNPPPREV].varname,
               "STATE_ANNUALNPPPREV");
        strcpy(state_metadata[STATE_ANNUALNPPPREV].long_name, "annualnppprev");
        strcpy(state_metadata[STATE_ANNUALNPPPREV].standard_name,
               "previous_year_total_annual_NPP");
        strcpy(state_metadata[STATE_ANNUALNPPPREV].units, "g m-2");
        strcpy(state_metadata[STATE_ANNUALNPPPREV].description,
               "total annual NPP from previous year");

        // STATE_CLITTER
        strcpy(state_metadata[STATE_CLITTER].varname, "STATE_CLITTER");
        strcpy(state_metadata[STATE_CLITTER].long_name, "clitter");
        strcpy(state_metadata[STATE_CLITTER].standard_name,
               "carbon_in_litter_pool");
        strcpy(state_metadata[STATE_CLITTER].units, "g m-2");
        strcpy(state_metadata[STATE_CLITTER].description,
               "carbon storage in litter pool");

        // STATE_CINTER
        strcpy(state_metadata[STATE_CINTER].varname, "STATE_CINTER");
        strcpy(state_metadata[STATE_CINTER].long_name, "cinter");
        strcpy(state_metadata[STATE_CINTER].standard_name,
               "carbon_in_intermediate_pool");
        strcpy(state_metadata[STATE_CINTER].units, "g m-2");
        strcpy(state_metadata[STATE_CINTER].description,
               "carbon storage in intermediate pool");

        // STATE_CSLOW
        strcpy(state_metadata[STATE_CSLOW].varname, "STATE_CSLOW");
        strcpy(state_metadata[STATE_CSLOW].long_name, "cslow");
        strcpy(state_metadata[STATE_CSLOW].standard_name,
               "carbon_in_slow_pool");
        strcpy(state_metadata[STATE_CSLOW].units, "g m-2");
        strcpy(state_metadata[STATE_CSLOW].description,
               "carbon storage in slow pool");
    }
    // STATE_SNOW_AGE
    strcpy(state_metadata[STATE_SNOW_AGE].varname, "STATE_SNOW_AGE");
    strcpy(state_metadata[STATE_SNOW_AGE].long_name, "snow_age");
    strcpy(state_metadata[STATE_SNOW_AGE].standard_name,
           "age_since_last_new_snow");
    strcpy(state_metadata[STATE_SNOW_AGE].units, "model_time_step");
    strcpy(state_metadata[STATE_SNOW_AGE].description,
           "number of model time steps since the last new snow");

    // STATE_SNOW_MELT_STATE
    strcpy(state_metadata[STATE_SNOW_MELT_STATE].varname,
           "STATE_SNOW_MELT_STATE");
    strcpy(state_metadata[STATE_SNOW_MELT_STATE].long_name, "snow_melt_state");
    strcpy(state_metadata[STATE_SNOW_MELT_STATE].standard_name,
           "snow_melting_phase");
    strcpy(state_metadata[STATE_SNOW_MELT_STATE].units,
           "1 melting, 0 not melting");
    strcpy(state_metadata[STATE_SNOW_MELT_STATE].description,
           "flag to indicate whether snowpack is in accumulation or melting phase");

    // STATE_SNOW_COVERAGE
    strcpy(state_metadata[STATE_SNOW_COVERAGE].varname, "STATE_SNOW_COVERAGE");
    strcpy(state_metadata[STATE_SNOW_COVERAGE].long_name, "snow_coverage");
    strcpy(state_metadata[STATE_SNOW_COVERAGE].standard_name,
           "snow_coverage_fraction");
    strcpy(state_metadata[STATE_SNOW_COVERAGE].units, "1");
    strcpy(state_metadata[STATE_SNOW_COVERAGE].description,
           "fraction of grid cell area covered by snow");

    // STATE_SNOW_WATER_EQUIVALENT
    strcpy(state_metadata[STATE_SNOW_WATER_EQUIVALENT].varname,
           "STATE_SNOW_WATER_EQUIVALENT");
    strcpy(state_metadata[STATE_SNOW_WATER_EQUIVALENT].long_name,
           "snow_water_equivalent");
    strcpy(state_metadata[STATE_SNOW_WATER_EQUIVALENT].standard_name,
           "snow_water_equivalent");
    strcpy(state_metadata[STATE_SNOW_WATER_EQUIVALENT].units, "m");
    strcpy(state_metadata[STATE_SNOW_WATER_EQUIVALENT].description,
           "snow water equivalent");

    // STATE_SNOW_SURF_TEMP
    strcpy(state_metadata[STATE_SNOW_SURF_TEMP].varname,
           "STATE_SNOW_SURF_TEMP");
    strcpy(state_metadata[STATE_SNOW_SURF_TEMP].long_name, "snow_surf_temp");
    strcpy(state_metadata[STATE_SNOW_SURF_TEMP].standard_name,
           "snow_surface_temperature");
    strcpy(state_metadata[STATE_SNOW_SURF_TEMP].units, "C");
    strcpy(state_metadata[STATE_SNOW_SURF_TEMP].description,
           "snow surface layer temperature");

    // STATE_SNOW_SURF_WATER
    strcpy(state_metadata[STATE_SNOW_SURF_WATER].varname,
           "STATE_SNOW_SURF_WATER");
    strcpy(state_metadata[STATE_SNOW_SURF_WATER].long_name, "snow_surf_water");
    strcpy(state_metadata[STATE_SNOW_SURF_WATER].standard_name,
           "snow_surface_liquid_water");
    strcpy(state_metadata[STATE_SNOW_SURF_WATER].units, "m");
    strcpy(state_metadata[STATE_SNOW_SURF_WATER].description,
           "liquid water content of the snow surface layer");

    // STATE_SNOW_PACK_TEMP
    strcpy(state_metadata[STATE_SNOW_PACK_TEMP].varname,
           "STATE_SNOW_PACK_TEMP");
    strcpy(state_metadata[STATE_SNOW_PACK_TEMP].long_name, "snow_pack_temp");
    strcpy(state_metadata[STATE_SNOW_PACK_TEMP].standard_name,
           "snow_pack_temperature");
    strcpy(state_metadata[STATE_SNOW_PACK_TEMP].units, "C");
    strcpy(state_metadata[STATE_SNOW_PACK_TEMP].description,
           "snow pack layer temperature");

    // STATE_SNOW_PACK_WATER
    strcpy(state_metadata[STATE_SNOW_PACK_WATER].varname,
           "STATE_SNOW_PACK_WATER");
    strcpy(state_metadata[STATE_SNOW_PACK_WATER].long_name, "snow_pack_water");
    strcpy(state_metadata[STATE_SNOW_PACK_WATER].standard_name,
           "snow_pack_liquid_water");
    strcpy(state_metadata[STATE_SNOW_PACK_WATER].units, "m");
    strcpy(state_metadata[STATE_SNOW_PACK_WATER].description,
           "liquid water content of the snow pack layer");

    // STATE_SNOW_DENSITY
    strcpy(state_metadata[STATE_SNOW_DENSITY].varname, "STATE_SNOW_DENSITY");
    strcpy(state_metadata[STATE_SNOW_DENSITY].long_name, "snow_density");
    strcpy(state_metadata[STATE_SNOW_DENSITY].standard_name,
           "snowpack_density");
    strcpy(state_metadata[STATE_SNOW_DENSITY].units, "kg m-3");
    strcpy(state_metadata[STATE_SNOW_DENSITY].description, "snowpack density");

    // STATE_SNOW_COLD_CONTENT
    strcpy(state_metadata[STATE_SNOW_COLD_CONTENT].varname,
           "STATE_SNOW_COLD_CONTENT");
    strcpy(state_metadata[STATE_SNOW_COLD_CONTENT].long_name,
           "snow_cold_content");
    strcpy(state_metadata[STATE_SNOW_COLD_CONTENT].standard_name,
           "snowpack_cold_content");
    strcpy(state_metadata[STATE_SNOW_COLD_CONTENT].units, "J m-2");
    strcpy(state_metadata[STATE_SNOW_COLD_CONTENT].description,
           "snowpack cold content");

    // STATE_SNOW_CANOPY
    strcpy(state_metadata[STATE_SNOW_CANOPY].varname, "STATE_SNOW_CANOPY");
    strcpy(state_metadata[STATE_SNOW_CANOPY].long_name, "snow_canopy");
    strcpy(state_metadata[STATE_SNOW_CANOPY].standard_name,
           "snow_water_equivalent_intercepted_in_canopy");
    strcpy(state_metadata[STATE_SNOW_CANOPY].units, "m");
    strcpy(state_metadata[STATE_SNOW_CANOPY].description,
           "snow interception storage in canopy");

    // STATE_SOIL_NODE_TEMP
    strcpy(state_metadata[STATE_SOIL_NODE_TEMP].varname,
           "STATE_SOIL_NODE_TEMP");
    strcpy(state_metadata[STATE_SOIL_NODE_TEMP].long_name, "soil_node_temp");
    strcpy(state_metadata[STATE_SOIL_NODE_TEMP].standard_name,
           "soil_node_temperature");
    strcpy(state_metadata[STATE_SOIL_NODE_TEMP].units, "C");
    strcpy(state_metadata[STATE_SOIL_NODE_TEMP].description,
           "soil temperature of each soil thermal node");

    // STATE_FOLIAGE_TEMPERATURE
    strcpy(state_metadata[STATE_FOLIAGE_TEMPERATURE].varname,
           "STATE_FOLIAGE_TEMPERATURE");
    strcpy(state_metadata[STATE_FOLIAGE_TEMPERATURE].long_name,
           "foliage_temperature");
    strcpy(state_metadata[STATE_FOLIAGE_TEMPERATURE].standard_name,
           "foliage_temperature");
    strcpy(state_metadata[STATE_FOLIAGE_TEMPERATURE].units, "C");
    strcpy(state_metadata[STATE_FOLIAGE_TEMPERATURE].description,
           "overstory vegetaion temperature");

    // STATE_ENERGY_LONGUNDEROUT
    strcpy(state_metadata[STATE_ENERGY_LONGUNDEROUT].varname,
           "STATE_ENERGY_LONGUNDEROUT");
    strcpy(state_metadata[STATE_ENERGY_LONGUNDEROUT].long_name,
           "energy_longunderout");
    strcpy(state_metadata[STATE_ENERGY_LONGUNDEROUT].standard_name,
           "longwave_out_from_understory");
    strcpy(state_metadata[STATE_ENERGY_LONGUNDEROUT].units, "W m-2");
    strcpy(state_metadata[STATE_ENERGY_LONGUNDEROUT].description,
           "outgoing longwave flux from understory vegetation");

    // STATE_ENERGY_SNOW_FLUX
    strcpy(state_metadata[STATE_ENERGY_SNOW_FLUX].varname,
           "STATE_ENERGY_SNOW_FLUX");
    strcpy(state_metadata[STATE_ENERGY_SNOW_FLUX].long_name,
           "energy_snow_flux");
    strcpy(state_metadata[STATE_ENERGY_SNOW_FLUX].standard_name,
           "snowpack_thermal_flux");
    strcpy(state_metadata[STATE_ENERGY_SNOW_FLUX].units, "W m-2");
    strcpy(state_metadata[STATE_ENERGY_SNOW_FLUX].description,
           "thermal flux through snowpack");

    // STATE_GRIDCELL_AVG_ALBEDO
    strcpy(state_metadata[STATE_AVG_ALBEDO].varname,
           "STATE_AVG_ALBEDO");
    strcpy(state_metadata[STATE_AVG_ALBEDO].long_name,
           "state_avg_albedo");
    strcpy(state_metadata[STATE_AVG_ALBEDO].standard_name,
           "state_gridcell_avg_albedo");
    strcpy(state_metadata[STATE_AVG_ALBEDO].units, "fraction");
    strcpy(state_metadata[STATE_AVG_ALBEDO].description,
           "gridcell averaged albedo");

    if (options.LAKES) {
        // STATE_LAKE_SOIL_MOISTURE
        strcpy(state_metadata[STATE_LAKE_SOIL_MOISTURE].varname,
               "STATE_LAKE_SOIL_MOISTURE");
        strcpy(state_metadata[STATE_LAKE_SOIL_MOISTURE].long_name,
               "lake_soil_moisture");
        strcpy(state_metadata[STATE_LAKE_SOIL_MOISTURE].standard_name,
               "lake_soil_moisture");
        strcpy(state_metadata[STATE_LAKE_SOIL_MOISTURE].units, "mm");
        strcpy(state_metadata[STATE_LAKE_SOIL_MOISTURE].description,
               "soil moisture below lake");

        // STATE_LAKE_SOIL_ICE
        strcpy(state_metadata[STATE_LAKE_SOIL_ICE].varname,
               "STATE_LAKE_SOIL_ICE");
        strcpy(state_metadata[STATE_LAKE_SOIL_ICE].long_name, "lake_soil_ice");
        strcpy(state_metadata[STATE_LAKE_SOIL_ICE].standard_name,
               "lake_soil_ice_content");
        strcpy(state_metadata[STATE_LAKE_SOIL_ICE].units, "mm");
        strcpy(state_metadata[STATE_LAKE_SOIL_ICE].description,
               "soil ice content below lake");

        if (options.CARBON) {
            // STATE_LAKE_CLITTER
            strcpy(state_metadata[STATE_LAKE_CLITTER].varname,
                   "STATE_LAKE_CLITTER");
            strcpy(state_metadata[STATE_LAKE_CLITTER].long_name,
                   "lake_clitter");
            strcpy(state_metadata[STATE_LAKE_CLITTER].standard_name,
                   "lake_carbon_in_litter_pool");
            strcpy(state_metadata[STATE_LAKE_CLITTER].units, "g m-2");
            strcpy(state_metadata[STATE_LAKE_CLITTER].description,
                   "carbon storage in litter pool below lake");

            // STATE_LAKE_CINTER
            strcpy(state_metadata[STATE_LAKE_CINTER].varname,
                   "STATE_LAKE_CINTER");
            strcpy(state_metadata[STATE_LAKE_CINTER].long_name, "lake_cinter");
            strcpy(state_metadata[STATE_LAKE_CINTER].standard_name,
                   "lake_carbon_in_intermediate_pool");
            strcpy(state_metadata[STATE_LAKE_CINTER].units, "g m-2");
            strcpy(state_metadata[STATE_LAKE_CINTER].description,
                   "carbon storage in intermediate pool below lake");

            // STATE_LAKE_CSLOW
            strcpy(state_metadata[STATE_LAKE_CSLOW].varname,
                   "STATE_LAKE_CSLOW");
            strcpy(state_metadata[STATE_LAKE_CSLOW].long_name, "lake_cslow");
            strcpy(state_metadata[STATE_LAKE_CSLOW].standard_name,
                   "lake_carbon_in_slow_pool");
            strcpy(state_metadata[STATE_LAKE_CSLOW].units, "g m-2");
            strcpy(state_metadata[STATE_LAKE_CSLOW].description,
                   "carbon storage in slow pool below lake");
        }

        // STATE_LAKE_SNOW_AGE
        strcpy(state_metadata[STATE_LAKE_SNOW_AGE].varname,
               "STATE_LAKE_SNOW_AGE");
        strcpy(state_metadata[STATE_LAKE_SNOW_AGE].long_name, "lake_snow_age");
        strcpy(state_metadata[STATE_LAKE_SNOW_AGE].standard_name,
               "lake_age_since_last_new_snow");
        strcpy(state_metadata[STATE_LAKE_SNOW_AGE].units, "model_time_step");
        strcpy(state_metadata[STATE_LAKE_SNOW_AGE].description,
               "number of model time steps since the last new snow on lake ice");

        // STATE_LAKE_SNOW_MELT_STATE
        strcpy(state_metadata[STATE_LAKE_SNOW_MELT_STATE].varname,
               "STATE_LAKE_SNOW_MELT_STATE");
        strcpy(state_metadata[STATE_LAKE_SNOW_MELT_STATE].long_name,
               "lake_snow_melt_state");
        strcpy(state_metadata[STATE_LAKE_SNOW_MELT_STATE].standard_name,
               "lake_snow_melting_phase");
        strcpy(state_metadata[STATE_LAKE_SNOW_MELT_STATE].units,
               "1 melting, 0 not melting");
        strcpy(state_metadata[STATE_LAKE_SNOW_MELT_STATE].description,
               "flag to indicate whether snowpack is in accumulation or melting phase on lake ice");

        // STATE_LAKE_SNOW_COVERAGE
        strcpy(state_metadata[STATE_LAKE_SNOW_COVERAGE].varname,
               "STATE_LAKE_SNOW_COVERAGE");
        strcpy(state_metadata[STATE_LAKE_SNOW_COVERAGE].long_name,
               "lake_snow_coverage");
        strcpy(state_metadata[STATE_LAKE_SNOW_COVERAGE].standard_name,
               "lake_snow_coverage_fraction");
        strcpy(state_metadata[STATE_LAKE_SNOW_COVERAGE].units, "1");
        strcpy(state_metadata[STATE_LAKE_SNOW_COVERAGE].description,
               "fraction of grid cell area covered by snow on lake ice");

        // STATE_LAKE_SNOW_WATER_EQUIVALENT
        strcpy(state_metadata[STATE_LAKE_SNOW_WATER_EQUIVALENT].varname,
               "STATE_LAKE_SNOW_WATER_EQUIVALENT");
        strcpy(state_metadata[STATE_LAKE_SNOW_WATER_EQUIVALENT].long_name,
               "lake_snow_water_equivalent");
        strcpy(state_metadata[STATE_LAKE_SNOW_WATER_EQUIVALENT].standard_name,
               "lake_snow_water_equivalent");
        strcpy(state_metadata[STATE_LAKE_SNOW_WATER_EQUIVALENT].units, "m");
        strcpy(state_metadata[STATE_LAKE_SNOW_WATER_EQUIVALENT].description,
               "lake snow water equivalent on lake ice");

        // STATE_LAKE_SNOW_SURF_TEMP
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_TEMP].varname,
               "STATE_LAKE_SNOW_SURF_TEMP");
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_TEMP].long_name,
               "lake_snow_surf_temp");
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_TEMP].standard_name,
               "lake_snow_surface_temperature");
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_TEMP].units, "C");
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_TEMP].description,
               "snow surface layer temperature on lake ice");

        // STATE_LAKE_SNOW_SURF_WATER
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_WATER].varname,
               "STATE_LAKE_SNOW_SURF_WATER");
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_WATER].long_name,
               "lake_snow_surf_water");
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_WATER].standard_name,
               "lake_snow_surface_temperature");
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_WATER].units, "m");
        strcpy(state_metadata[STATE_LAKE_SNOW_SURF_WATER].description,
               "liquid water content of the snow surface layer on lake ice");

        // STATE_LAKE_SNOW_PACK_TEMP
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_TEMP].varname,
               "STATE_LAKE_SNOW_PACK_TEMP");
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_TEMP].long_name,
               "lake_snow_pack_temp");
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_TEMP].standard_name,
               "lake_snow_pack_temperature");
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_TEMP].units, "C");
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_TEMP].description,
               "snow pack layer temperature on lake ice");

        // STATE_LAKE_SNOW_PACK_WATER
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_WATER].varname,
               "STATE_LAKE_SNOW_PACK_WATER");
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_WATER].long_name,
               "lake_snow_pack_water");
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_WATER].standard_name,
               "lake_snow_surface_liquid_water");
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_WATER].units, "m");
        strcpy(state_metadata[STATE_LAKE_SNOW_PACK_WATER].description,
               "liquid water content of the snow surface layer on lake ice");

        // STATE_LAKE_SNOW_DENSITY
        strcpy(state_metadata[STATE_LAKE_SNOW_DENSITY].varname,
               "STATE_LAKE_SNOW_DENSITY");
        strcpy(state_metadata[STATE_LAKE_SNOW_DENSITY].long_name,
               "lake_snow_density");
        strcpy(state_metadata[STATE_LAKE_SNOW_DENSITY].standard_name,
               "lake_snowpack_density");
        strcpy(state_metadata[STATE_LAKE_SNOW_DENSITY].units, "kg m-3");
        strcpy(state_metadata[STATE_LAKE_SNOW_DENSITY].description,
               "snowpack density on lake ice");

        // STATE_LAKE_SNOW_COLD_CONTENT
        strcpy(state_metadata[STATE_LAKE_SNOW_COLD_CONTENT].varname,
               "STATE_LAKE_SNOW_COLD_CONTENT");
        strcpy(state_metadata[STATE_LAKE_SNOW_COLD_CONTENT].long_name,
               "lake_snow_cold_content");
        strcpy(state_metadata[STATE_LAKE_SNOW_COLD_CONTENT].standard_name,
               "lake_snowpack_cold_content");
        strcpy(state_metadata[STATE_LAKE_SNOW_COLD_CONTENT].units, "J m-2");
        strcpy(state_metadata[STATE_LAKE_SNOW_COLD_CONTENT].description,
               "snowpack cold content on lake ice");

        // STATE_LAKE_SNOW_CANOPY
        strcpy(state_metadata[STATE_LAKE_SNOW_CANOPY].varname,
               "STATE_LAKE_SNOW_CANOPY");
        strcpy(state_metadata[STATE_LAKE_SNOW_CANOPY].long_name,
               "lake_snow_canopy");
        strcpy(state_metadata[STATE_LAKE_SNOW_CANOPY].standard_name,
               "lake_snow_water_equivalent_intercepted_in_canopy");
        strcpy(state_metadata[STATE_LAKE_SNOW_CANOPY].units, "m");
        strcpy(state_metadata[STATE_LAKE_SNOW_CANOPY].description,
               "snow interception storage in canopy on lake ice");

        // STATE_LAKE_SOIL_NODE_TEMP
        strcpy(state_metadata[STATE_LAKE_SOIL_NODE_TEMP].varname,
               "STATE_LAKE_SOIL_NODE_TEMP");
        strcpy(state_metadata[STATE_LAKE_SOIL_NODE_TEMP].long_name,
               "lake_soil_node_temp");
        strcpy(state_metadata[STATE_LAKE_SOIL_NODE_TEMP].standard_name,
               "lake_soil_node_temperature");
        strcpy(state_metadata[STATE_LAKE_SOIL_NODE_TEMP].units, "C");
        strcpy(state_metadata[STATE_LAKE_SOIL_NODE_TEMP].description,
               "soil temperature of each soil thermal node below lake");

        // STATE_LAKE_ACTIVE_LAYERS
        strcpy(state_metadata[STATE_LAKE_ACTIVE_LAYERS].varname,
               "STATE_LAKE_ACTIVE_LAYERS");
        strcpy(state_metadata[STATE_LAKE_ACTIVE_LAYERS].long_name,
               "lake_active_layers");
        strcpy(state_metadata[STATE_LAKE_ACTIVE_LAYERS].standard_name,
               "lake_active_layers");
        strcpy(state_metadata[STATE_LAKE_ACTIVE_LAYERS].units, "-");
        strcpy(state_metadata[STATE_LAKE_ACTIVE_LAYERS].description,
               "number of nodes whose corresponding layers currently contain water");

        // STATE_LAKE_LAYER_DZ
        strcpy(state_metadata[STATE_LAKE_LAYER_DZ].varname,
               "STATE_LAKE_LAYER_DZ");
        strcpy(state_metadata[STATE_LAKE_LAYER_DZ].long_name, "lake_layer_dz");
        strcpy(state_metadata[STATE_LAKE_LAYER_DZ].standard_name,
               "lake_thickness_layer_below_surface");
        strcpy(state_metadata[STATE_LAKE_LAYER_DZ].units, "m");
        strcpy(state_metadata[STATE_LAKE_LAYER_DZ].description,
               "vertical thickness of all horizontal lake water layers below the surface layer");

        // STATE_LAKE_SURF_LAYER_DZ
        strcpy(state_metadata[STATE_LAKE_SURF_LAYER_DZ].varname,
               "STATE_LAKE_SURF_LAYER_DZ");
        strcpy(state_metadata[STATE_LAKE_SURF_LAYER_DZ].long_name,
               "lake_surf_layer_dz");
        strcpy(state_metadata[STATE_LAKE_SURF_LAYER_DZ].standard_name,
               "lake_thickness_surface_layer");
        strcpy(state_metadata[STATE_LAKE_SURF_LAYER_DZ].units, "m");
        strcpy(state_metadata[STATE_LAKE_SURF_LAYER_DZ].description,
               "vertical thickness of surface water layer in lake");

        // STATE_LAKE_DEPTH
        strcpy(state_metadata[STATE_LAKE_DEPTH].varname, "STATE_LAKE_DEPTH");
        strcpy(state_metadata[STATE_LAKE_DEPTH].long_name, "lake_depth");
        strcpy(state_metadata[STATE_LAKE_DEPTH].standard_name,
               "lake_liquid_water_depth");
        strcpy(state_metadata[STATE_LAKE_DEPTH].units, "m");
        strcpy(state_metadata[STATE_LAKE_DEPTH].description,
               "distance from surface to deepest point in lake");

        // STATE_LAKE_LAYER_SURF_AREA
        strcpy(state_metadata[STATE_LAKE_LAYER_SURF_AREA].varname,
               "STATE_LAKE_LAYER_SURF_AREA");
        strcpy(state_metadata[STATE_LAKE_LAYER_SURF_AREA].long_name,
               "lake_layer_surf_area");
        strcpy(state_metadata[STATE_LAKE_LAYER_SURF_AREA].standard_name,
               "lake_node_surface_area");
        strcpy(state_metadata[STATE_LAKE_LAYER_SURF_AREA].units, "m2");
        strcpy(state_metadata[STATE_LAKE_LAYER_SURF_AREA].description,
               "surface area of liquid water in lake at each node");

        // STATE_LAKE_SURF_AREA
        strcpy(state_metadata[STATE_LAKE_SURF_AREA].varname,
               "STATE_LAKE_SURF_AREA");
        strcpy(state_metadata[STATE_LAKE_SURF_AREA].long_name,
               "lake_surf_area");
        strcpy(state_metadata[STATE_LAKE_SURF_AREA].standard_name,
               "lake_surface_area");
        strcpy(state_metadata[STATE_LAKE_SURF_AREA].units, "m2");
        strcpy(state_metadata[STATE_LAKE_SURF_AREA].description,
               "surface area of liquid plus ice water on lake surface");

        // STATE_LAKE_VOLUME
        strcpy(state_metadata[STATE_LAKE_VOLUME].varname, "STATE_LAKE_VOLUME");
        strcpy(state_metadata[STATE_LAKE_VOLUME].long_name, "lake_volume");
        strcpy(state_metadata[STATE_LAKE_VOLUME].standard_name, "lake_volume");
        strcpy(state_metadata[STATE_LAKE_VOLUME].units, "m3");
        strcpy(state_metadata[STATE_LAKE_VOLUME].description,
               "lake total volume including liquid water equivalent of lake ice");

        // STATE_LAKE_LAYER_TEMP
        strcpy(state_metadata[STATE_LAKE_LAYER_TEMP].varname,
               "STATE_LAKE_LAYER_TEMP");
        strcpy(state_metadata[STATE_LAKE_LAYER_TEMP].long_name,
               "lake_layer_temp");
        strcpy(state_metadata[STATE_LAKE_LAYER_TEMP].standard_name,
               "lake_layer_temp");
        strcpy(state_metadata[STATE_LAKE_LAYER_TEMP].units, "C");
        strcpy(state_metadata[STATE_LAKE_LAYER_TEMP].description,
               "lake water temperature at each node");

        // STATE_LAKE_AVERAGE_TEMP
        strcpy(state_metadata[STATE_LAKE_AVERAGE_TEMP].varname,
               "STATE_LAKE_AVERAGE_TEMP");
        strcpy(state_metadata[STATE_LAKE_AVERAGE_TEMP].long_name,
               "lake_average_temp");
        strcpy(state_metadata[STATE_LAKE_AVERAGE_TEMP].standard_name,
               "lake_average_temperature");
        strcpy(state_metadata[STATE_LAKE_AVERAGE_TEMP].units, "C");
        strcpy(state_metadata[STATE_LAKE_AVERAGE_TEMP].description,
               "average liquid water temperature of entire lake");

        // STATE_LAKE_ICE_AREA_FRAC
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC].varname,
               "STATE_LAKE_ICE_AREA");
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC].long_name,
               "lake_ice_area");
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC].standard_name,
               "lake_ice_coverage");
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC].units, "m2");
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC].description,
               "area of ice coverage on lake at beginning of time step");

        // STATE_LAKE_ICE_AREA_FRAC_NEW
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC_NEW].varname,
               "STATE_LAKE_ICE_AREA_NEW");
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC_NEW].long_name,
               "lake_ice_area_new");
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC_NEW].standard_name,
               "lake_ice_area_new");
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC_NEW].units, "m2");
        strcpy(state_metadata[STATE_LAKE_ICE_AREA_FRAC_NEW].description,
               "area of ice coverage on lake at end of time step");

        // STATE_LAKE_ICE_WATER_EQUIVALENT
        strcpy(state_metadata[STATE_LAKE_ICE_WATER_EQUIVALENT].varname,
               "STATE_LAKE_ICE_WATER_EQUIVALENT");
        strcpy(state_metadata[STATE_LAKE_ICE_WATER_EQUIVALENT].long_name,
               "lake_ice_water_equivalent");
        strcpy(state_metadata[STATE_LAKE_ICE_WATER_EQUIVALENT].standard_name,
               "lake_ice_water_equivalent");
        strcpy(state_metadata[STATE_LAKE_ICE_WATER_EQUIVALENT].units, "m3");
        strcpy(state_metadata[STATE_LAKE_ICE_WATER_EQUIVALENT].description,
               "liquid water equivalent volume of lake ice");

        // STATE_LAKE_ICE_HEIGHT
        strcpy(state_metadata[STATE_LAKE_ICE_HEIGHT].varname,
               "STATE_LAKE_ICE_HEIGHT");
        strcpy(state_metadata[STATE_LAKE_ICE_HEIGHT].long_name,
               "lake_ice_height");
        strcpy(state_metadata[STATE_LAKE_ICE_HEIGHT].standard_name,
               "lake_ice_height_thickest");
        strcpy(state_metadata[STATE_LAKE_ICE_HEIGHT].units, "m");
        strcpy(state_metadata[STATE_LAKE_ICE_HEIGHT].description,
               "lake ice height at ghickest point");

        // STATE_LAKE_ICE_TEMP
        strcpy(state_metadata[STATE_LAKE_ICE_TEMP].varname,
               "STATE_LAKE_ICE_TEMP");
        strcpy(state_metadata[STATE_LAKE_ICE_TEMP].long_name, "lake_ice_temp");
        strcpy(state_metadata[STATE_LAKE_ICE_TEMP].standard_name,
               "lake_ice_temperature");
        strcpy(state_metadata[STATE_LAKE_ICE_TEMP].units, "C");
        strcpy(state_metadata[STATE_LAKE_ICE_TEMP].description,
               "lake ice temperature");

        // STATE_LAKE_ICE_SWE
        strcpy(state_metadata[STATE_LAKE_ICE_SWE].varname,
               "STATE_LAKE_ICE_SWE");
        strcpy(state_metadata[STATE_LAKE_ICE_SWE].long_name, "lake_ice_swe");
        strcpy(state_metadata[STATE_LAKE_ICE_SWE].standard_name,
               "lake_snow_water_equivalent");
        strcpy(state_metadata[STATE_LAKE_ICE_SWE].units, "m");
        strcpy(state_metadata[STATE_LAKE_ICE_SWE].description,
               "liquid water equivalent depth of lake snow");

        // STATE_LAKE_ICE_SNOW_SURF_TEMP
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_TEMP].varname,
               "STATE_LAKE_ICE_SNOW_SURF_TEMP");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_TEMP].long_name,
               "lake_ice_snow_surf_temp");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_TEMP].standard_name,
               "lake_snow_surface_temperature");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_TEMP].units, "C");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_TEMP].description,
               "temperature of snow surface layer of lake snow");

        // STATE_LAKE_ICE_SNOW_PACK_TEMP
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_TEMP].varname,
               "STATE_LAKE_ICE_SNOW_PACK_TEMP");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_TEMP].long_name,
               "lake_ice_snow_pack_temp");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_TEMP].standard_name,
               "lake_ice_snow_pack_temperature");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_TEMP].units, "C");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_TEMP].description,
               "temperature of snow pack layer of lake snow");

        // STATE_LAKE_ICE_SNOW_COLD_CONTENT
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_COLD_CONTENT].varname,
               "STATE_LAKE_ICE_SNOW_COLD_CONTENT");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_COLD_CONTENT].long_name,
               "lake_ice_snow_cold_content");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_COLD_CONTENT].standard_name,
               "lake_ice_snow_cold_content");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_COLD_CONTENT].units, "J m-2");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_COLD_CONTENT].description,
               "snowpack cold content of snow lake");

        // STATE_LAKE_ICE_SNOW_SURF_WATER
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_WATER].varname,
               "STATE_LAKE_ICE_SNOW_SURF_WATER");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_WATER].long_name,
               "lake_ice_snow_surf_water");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_WATER].standard_name,
               "lake_ice_snow_surface_liquid_water");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_WATER].units, "m");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_SURF_WATER].description,
               "liquid water content of surface snow layer of lake snow");

        // STATE_LAKE_ICE_SNOW_PACK_WATER
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_WATER].varname,
               "STATE_LAKE_ICE_SNOW_PACK_WATER");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_WATER].long_name,
               "lake_ice_snow_pack_water");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_WATER].standard_name,
               "lake_ice_snow_pack_liquid_water");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_WATER].units, "m");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_PACK_WATER].description,
               "liquid water content of pack snow layer of lake snow");

        // STATE_LAKE_ICE_SNOW_ALBEDO
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_ALBEDO].varname,
               "STATE_LAKE_ICE_SNOW_ALBEDO");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_ALBEDO].long_name,
               "lake_ice_snow_albedo");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_ALBEDO].standard_name,
               "lake_ice_snow_albedo");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_ALBEDO].units, "1");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_ALBEDO].description,
               "albedo of lake snow");

        // STATE_LAKE_ICE_SNOW_DEPTH
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_DEPTH].varname,
               "STATE_LAKE_ICE_SNOW_DEPTH");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_DEPTH].long_name,
               "lake_ice_snow_depth");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_DEPTH].standard_name,
               "lake_ice_snow_depth");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_DEPTH].units, "m");
        strcpy(state_metadata[STATE_LAKE_ICE_SNOW_DEPTH].description,
               "depth of snow on lake ice");
    }

    // STATE_ROUT_RING
    state_metadata_rout_extension();
}
